% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% sdm_comparison_2015.m
%
% Purpose: script for simple comparison of BrainVoyager design matrix files (*.sdm)   
%
% Requirements: Matlab R2014a or newer and NeuroElf
%
% For activation of script: load in Matlab, press 'run'. In case of
% questions from Matlab, select 'Add to path'.
% The script will ask for the *.sdm files via pop-up dialogs.
% 
% Output: a figure (also saved to disk) and a text file.
% 
% HB, Brain Innovation, Apr '14; latest update 14-05-15
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% get user input
comparisonname = inputdlg('Please enter a name for the comparison');
[FileName,PathName] = uigetfile('*.sdm','Please select the *.sdm file 1...');
sdm1 = [PathName FileName];
sdm1data=xff(sdm1);
sdm1name = inputdlg('Please enter a short name for sdm 1');
[FileName,PathName] = uigetfile('*.sdm','Please select the *.sdm file 2...');
sdm2 = [PathName FileName];
sdm2data=xff(sdm2)
sdm2name = inputdlg('Please enter a short name for sdm 2');

% plot figure
colors = {'m', 'c', 'r', 'g', 'b', 'k', 'y', 'm--o', 'c--o', 'r--o', 'g--o', 'b--o', 'k--o', 'y--o', 'm:', 'c:', 'r:', 'g:', 'b:', 'k:','y:'}
h1 = figure;
subplot(1,3,1);
for (i=1:sdm1data.NrOfPredictors)
plot(sdm1data.SDMMatrix(:,i), colors{i})
hold on
end
title(['SDM ' sdm1name{1}])
xlabel('time')
subplot(1,3,2);
for (i=1:sdm2data.NrOfPredictors)
plot(sdm2data.SDMMatrix(:,i), colors{i})
hold on
title(['SDM ' sdm2name{1}]);
xlabel('time')
end
minpr = min(sdm1data.NrOfPredictors, sdm2data.NrOfPredictors);
subplot(1,3,3)
for (i=1:minpr)
diff(i) = sum(sdm1data.SDMMatrix(:,i)-sdm2data.SDMMatrix(:,i));
end
bar(diff)
axis([1 sdm2data.NrOfPredictors -10 10])
title(['comparison (subtracted); number of predictors: ' num2str(sdm2data.NrOfPredictors)])

% write figure
[pathstr, name, ext] = fileparts(sdm1)
saveas(h1,[pathstr filesep 'sdm_file_comparison_' comparisonname{1} '.png']) 

% write log file
fid = fopen([pathstr filesep 'sdm_file_comparison_' comparisonname{1} '.txt'],'w'); 
fprintf(fid, '~~~ Comparison: %s ~~~\n\n', comparisonname{1}); 
fprintf(fid, 'File 1: %s\n', sdm1); 
fprintf(fid, 'File 2: %s\n', sdm2);
fprintf(fid, 'NrOfPredictors file 1: %d\n', sdm1data.NrOfPredictors); 
fprintf(fid, 'NrOfPredictors file 2: %d\n', sdm2data.NrOfPredictors);
for (i=1:minpr)
    fprintf(fid, 'Sum of difference in predictor %d (%s - %s): %4.4f\n', i,sdm1data.PredictorNames{i},sdm2data.PredictorNames{i}, diff(i));
end
fclose(fid);
disp('Finished *.sdm comparison script');


 